@@ -8,6 +8,7 @@ import os
 
 import pytest
 import requests
+from playwright.sync_api import expect
 from utils import run_command
 
 from univention.udm import UDM
@@ -64,6 +65,7 @@ def test_univention_keycloak_legacy_flow_config(keycloak_administrator_connectio
 def test_legacy_authorization_saml(legacy_authorization_setup_saml, keycloak_config, keycloak_administrator_connection, portal_login_via_keycloak):
     # verify logon not possible
     page = portal_login_via_keycloak(legacy_authorization_setup_saml.user, 'univention', verify_login=False)
+    expect(page.locator('#kc-content-wrapper'), 'kc-content-wrapper not visible').to_be_visible()
     assert 'You do not have the needed privileges to access' in page.content()
 
     # add user to group
@@ -94,7 +96,7 @@ def test_legacy_authorization_oidc(legacy_authorization_setup_oidc, keycloak_con
             'grant_type': 'password',
         },
     )
-    assert resp.json().get('error') == 'unknown_error'  # https://github.com/keycloak/keycloak/issues/13368
+    assert 'You do not have the needed privileges to access' in resp.text
 
     # add user to group
     udm = UDM.admin().version(2)
